#ifndef PROPINFOBASE_H
#define PROPINFOBASE_H

#include <myXML_Document.hpp>
#include <map>
#include "AtmModel.h"
#include "EarthModel.h"
#include "json_functions.h"

enum proptypes
{
    ST_PROP = 0,
    KEPLER_PROP,
    PROGNOZ_PROP,
    SGP_PROP
};

class PropInfoBase
{
public:
    PropInfoBase()
    {
    };
    PropInfoBase(
        std::string lightModel,
        EarthModel earthModel,
        AtmModel atmModel,
        const bool sun,
        const bool moon,
        const bool prec_itrf,
        const int type);

    bool Load(myXML::Contain* parent);
    void load(const jsonval& parent);
    bool IsSun() const { return m_sun; }
    bool IsMoon() const { return m_moon; }
    int GetType() const { return m_type; }
    bool is_prec_itrf() const { return m_prec_itrf; }
    const AtmModel& GetAtmModel() const { return m_atmModel; }
    const EarthModel& GetEarthModel() const { return m_earthModel; }
    std::string GetLightModel() const { return m_lightModel; }
    std::string GetAsXML() const;
    void ToXml(std::ostream& outs) const;
private:

    static std::string TypeConvert(int value) ;
    static int TypeConvert(const std::string& value);

    AtmModel m_atmModel;
    EarthModel m_earthModel;
    std::string m_lightModel;
    bool m_sun;
    bool m_moon;
    int m_type;
    int m_id;
    bool m_prec_itrf {false};
};

typedef std::map<int, PropInfoBase> PropInfoBases;
typedef PropInfoBase MotionModel;

#endif
